@@ -32,10 +32,13 @@
 
 #include <iostream>
 #include "Knots.h"
-#include <JAGS/JRmath.h>
+#include <JRmath.h>
+#include <distribution/Distribution.h>
+#include <distribution/ScalarDist.h>
 #include <vector>
 #include <set>
 
+
 using std::vector;
 using std::set;
 
@@ -63,6 +66,7 @@ unsigned int Knots::calcMaxDelta(unsigned int const &K, TypeOfUpdate type) const
 	
   if(type == Birth)
     return std::min(_maxK - K, static_cast<unsigned int>(7));
+
 	
   if(type == Death)
     return std::min(K - _minK, static_cast<unsigned int>(7));
@@ -79,7 +83,7 @@ unsigned int Knots::rPoisT(double const &lambda, unsigned int const &T, RNG * co
   if(T == 1)
     return 1;
 	
-  double p[T];
+  vector<double> p(T);
 	
 	
   p[0] = std::exp(- lambda);
@@ -181,17 +185,28 @@ double Knots::removeFromProposedT(unsigned int const &T)
 
 
 
-Knots::Knots(unsigned int nchain, double const * PriorForT, unsigned int const * KLimits, double const * TLimits):
-  _nchain(nchain),
+Knots::Knots(unsigned int nchain, double const * PriorForT, StochasticNode const * knotsNode, double const * TLimits):
+
   _aPriorForT(PriorForT[0]),  //a and b for beta prior of Knots
   _bPriorForT(PriorForT[1]),
-  _minK(KLimits[0]), //min and max number of knots
-  _maxK(KLimits[1]),
   _minT(TLimits[0]),    //min and max interval on which the Knots can fall //like in WinBUGS minT is also the position of Knot0 (which is not deemed to be part of _...T)	
-  _maxT(TLimits[1])
+  _maxT(TLimits[1]),
+  _nchain(nchain)
   
 {
 
+    _knotsNode = knotsNode;
+
+    double tmpDMinK;
+    double tmpDMaxK;
+
+    _knotsNode->support(&tmpDMinK, &tmpDMaxK, 1, 0);
+
+    _minK = static_cast<unsigned int>(tmpDMinK);
+    _maxK = static_cast<unsigned int>(tmpDMaxK);
+    //std::cout << "Lower: " << _minK << " Upper: " << _maxK << std::endl;
+
+
   //std::cout << "beta priors are: " << _aPriorForT << " and " << _bPriorForT << std::endl;
   //number of knots
   _currentK = new unsigned int[_nchain];
@@ -369,7 +384,21 @@ double Knots::acceptProbBalance(unsigned int const &chain, TypeOfUpdate type) co
   double ans = 0;
 	
   //K
-  ans += std::log(1.0 / (_maxK - _minK)) - std::log(1.0 / (_maxK - _minK));
+  
+  //ans += std::log(1.0 / (_maxK - _minK)) - std::log(1.0 / (_maxK - _minK));
+  double tmpKnots = _proposedK;
+  ans += static_cast<ScalarDist const *>(_knotsNode->distribution())->logLikelihood( tmpKnots,
+										     _knotsNode->parameters(chain),
+										     _knotsNode->lowerLimit(chain),
+										     _knotsNode->upperLimit(chain));
+
+  tmpKnots = _currentK[chain];
+
+
+  ans -= static_cast<ScalarDist const *>(_knotsNode->distribution())->logLikelihood( tmpKnots,
+										     _knotsNode->parameters(chain),
+										     _knotsNode->lowerLimit(chain),
+										     _knotsNode->upperLimit(chain));
 	
 	
 	
@@ -558,6 +587,12 @@ double Knots::minT() const
   return _minT;
 }
 
+unsigned int Knots::maxK() const
+{
+  return _maxK;
+}
+
+
 void Knots::acceptProposedValues(unsigned int const &chain)
 {
   _currentK[chain] = _proposedK;
